@@ -38,10 +38,10 @@ class LangC(SetProject):
 
 #include <stdio.h>
 
-int main(int argc, char **argv) {{
+int main(int argc, char **argv) {
 \t/* code here */
 \treturn 0;
-}}""")
+}""")
 
         try:
             for gotFile in self.path.rglob("*.h"):
@@ -69,10 +69,10 @@ int main(int argc, char **argv) {{
 
 CC     = {self.compiler}
 CFLAG  = -Wall -std=c99
-CDFLAG = -Wall -std=c99 -g
+CDFLAG := ${{CFLAG}} -g
 LD     = {self.compiler}
-LDFLAG = -v
 LFLAG  =
+LDFLAG := ${{LFLAG}} -v
 
 
 SRC_DIR   = src
@@ -172,7 +172,7 @@ int main(int argc, char **argv) {
 \treturn 0;
 }""")
             else:
-                file.writelines(f"""//main file
+                file.writelines("""//main file
 
 #include <bits/stdc++.h>
 
@@ -207,7 +207,7 @@ using namespace std;
 #define eb emplace_back
 #define ab(a) (a < 0)?(-1*(a)):(a)
 #define mset(a,b,c) loop(i,0,(b)) (a)[i]=(c)
-#define asum(a,b,c) {{ int i = 0; (c) = 0; repd(i, b) (c)+=(a)[i]; }}
+#define asum(a,b,c) { int i = 0; (c) = 0; repd(i, b) (c)+=(a)[i]; }
 #define fe first
 #define se second
 #define mp make_pair
@@ -235,89 +235,103 @@ using namespace std;
 	cout << fixed << showpoint; \
 	cout << setprecision(x);
 #define nl "\\n"
-#define br cout << "\\n";
+#define br cout << "\\n"
 
 #define fileI(name) \\
-	freopen(name".in", "r", stdin);
-#define fileIO(name) \\
+	freopen(name".in", "r", stdin)
+#define fileIO(name) { \\
 	freopen(name".in", "r", stdin); \\
-	freopen(name".out", "w", stdout);
-#define FAST_IO \\
+	freopen(name".out", "w", stdout); \\
+}
+#define FAST_IO { \\
 	ios_base::sync_with_stdio(false); \\
 	cin.tie(NULL); \\
-	cout.tie(NULL);
+	cout.tie(NULL); \\
+}
 
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wcomment"
 
-typedef vector<int> vi;
-typedef vector<vector<int>> vvi;
-typedef vector<string> vs;
-typedef vector<vector<string>> vvs;
-typedef vector<double> vd;
-typedef vector<vector<double>> vvd;
-typedef pair<ll, ll> pll;
-typedef pair<int, int> pii;
-typedef vector<pll> vpll;
-typedef vector<pii> vpii;
+using vi = vector<int>;
+using vvi = vector<vi>;
+using vs = vector<string>;
+using vvs = vector<vs>;
+using vd = vector<double>;
+using vvd = vector<vd>;
+using pii = pair<int, int>;
+using pll = pair<ll, ll>;
+using vpll = vector<pll>;
+using vpii = vector<pii>;
+
 mt19937_64 rang(chrono::high_resolution_clock::now().time_since_epoch().count());
-int rngi(int lim) {{
+int rngi(int lim) {
 	uniform_int_distribution<int> uid(0,(lim)-1);
 	return uid(rang);
-}}
-double rngr(double lim) {{
+}
+double rngr(double lim) {
 	uniform_real_distribution<double> urd(0,(lim)-1);
 	return urd(rang);
-}}
+}
 
-template<typename T> T gcd(T a, T b) {{ return ((b)?__gcd(a,b):(a)); }}
-template<typename T> T lcm(T a, T b) {{ return ((a)*((b)/gcd(a,b))); }}
+template<typename T> T gcd(T a, T b) { return ((b)?__gcd(a,b):(a)); }
+template<typename T> T lcm(T a, T b) { return ((a)*((b)/gcd(a,b))); }
 
-inline void tokenize(const string& str, vs& out, const char&& delim) {{
+inline void tokenize(const string& str, vs& out, const char&& delim) {
 	stringstream ss(str);
 	string s;
 	while (getline(ss, s, delim)) out.pb(s);
-}}
-inline void tokenize(const string& str, vd& out, const char&& delim) {{
+}
+inline void tokenize(const string& str, vd& out, const char&& delim) {
 	stringstream ss(str);
-	for (double i; ss >> i;) {{ out.pb(i); if (ss.peek() == delim) ss.ignore(); }}
-}}
-inline void tokenize(const string& str, vi& out, const char&& delim) {{
+	for (double i; ss >> i;) { out.pb(i); if (ss.peek() == delim) ss.ignore(); }
+}
+inline void tokenize(const string& str, vi& out, const char&& delim) {
 	stringstream ss(str);
-	for (int i; ss >> i;) {{ out.pb(i); if (ss.peek() == ',') ss.ignore(); }}
-}}
-inline void ltrim(string& s) {{ s.erase(s.begin(), find_if(all(s), not1(ptr_fun<int, int>(isspace)))); }}
-inline void rtrim(string& s) {{ s.erase(find_if(rall(s), not1(ptr_fun<int, int>(isspace))).base(), s.end()); }}
-inline void trim(string& s) {{ ltrim(s); rtrim(s); }}
-inline string cltrim(string s) {{ ltrim(s); return s; }}
-inline string crtrim(string s) {{ rtrim(s); return s; }}
+	for (int i; ss >> i;) { out.pb(i); if (ss.peek() == delim) ss.ignore(); }
+}
+inline void print_mat(const vvi& t) {
+	if(0 == t.size()) {
+		cout << "[WW] Empty Matrix!!!" << nl;
+		return;
+	}
+	rep(i, t.size()) {
+		rep(j, t[0].size()) cout << t[i][j] << " ";
+		br;
+	}
+}
+inline void ltrim(string& s) { s.erase(s.begin(), find_if(all(s), not1(ptr_fun<int, int>(isspace)))); }
+inline void rtrim(string& s) { s.erase(find_if(rall(s), not1(ptr_fun<int, int>(isspace))).base(), s.end()); }
+inline void trim(string& s) { ltrim(s); rtrim(s); }
+inline string cltrim(string s) { ltrim(s); return s; }
+inline string crtrim(string s) { rtrim(s); return s; }
 
 void solvethetestcase();
 
-signed main() {{
+signed main() {
 	//comment when using scanf, printf
-	FAST_IO
+	FAST_IO;
 
 	//set the seed
 	//srand(chrono::high_resolution_clock::now().time_since_epoch().count());
 
 	//comment for input through console
-	fileI("input")
+	fileI("input");
 
 	int t = 1;
 	//(uncomment for multiple test cases)
 	//cin >> t;
-	loopl (testcase, 1, t + 1) {{
+	//cin.ignore();
+	loopl (testcase, 1, t + 1) {
 		//(uncomment for multiple test cases)
 		//cout << "Case #" << testcase << ": ";
 		//br;
 		solvethetestcase();
-	}}
-}}
+	}
+}
 
-void solvethetestcase() {{
+void solvethetestcase() {
 	//write here
-}}
+}
 
 #pragma GCC diagnostic pop""")
 
@@ -348,10 +362,10 @@ void solvethetestcase() {{
 
 CC     = {self.compiler}
 CFLAG  = -Wall -std=c++14
-CDFLAG = -Wall -std=c++14 -g
+CDFLAG := ${{CFLAG}} -g
 LD     = {self.compiler}
-LDFLAG = -v
 LFLAG  =
+LDFLAG := ${{LFLAG}} -v
 
 
 SRC_DIR   = src
